/* Copyright (c) 2018, 2020, The Linux Foundation. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * * Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 *  with the distribution.
 *   * Neither the name of The Linux Foundation nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#include <Library/ArmSmcLib.h>
#include "BootLinux.h"

#define HYP_BOOTINFO_MAGIC   0xC06B0071
#define HYP_BOOTINFO_VERSION 1
#define HYP_MAX_NUM_DTBOS    4

typedef struct hyp_boot_info {
    UINT32 hyp_bootinfo_magic;
    UINT32 hyp_bootinfo_version;
    /* Size of this structure, in bytes */
    UINT32 hyp_bootinfo_size;

    UINT32 pil_enable;

    struct {
        /* HYP_VM_TYPE_ */
        UINT32 vm_type;
        /*Number of dtbos provided */
        UINT32 num_dtbos;

        union {
            struct {
                UINT64 dtbo_base;
                UINT64 dtbo_size;
            } linux_aarch64[HYP_MAX_NUM_DTBOS];
            /* union padding */
            UINT32 vm_info[16];
        } info;
    } primary_vm_info;
} __attribute__ ((packed)) HypBootInfo;

/* SCM call related functions */
HypBootInfo *GetVmData (VOID);
BOOLEAN IsVmEnabled (VOID);
EFI_STATUS CheckAndSetVmData (BootParamlist *BootParamlistPtr);
VOID DisableHypUartUsageForLogging (VOID);
